searchData={"items":[{"type":"module","title":"Cldr.Calendar.Composite","doc":"A composite calendar is one in which a certain range of dates\nis interpreted in one calendar and a different range of dates\nis interpreted in a different calendar.\n\nThe canonical example is the transition from the Julian to\nGregorian calendar for European countries during the 16th to\n20th centuries.\n\nA configuration is simply a list of dates in the the\nappropriate calendar indicating when the calendar transitions\noccur.\n\nFor example, assuming England moved from the Julian to\nGregorian calendar on `14th of September, 1752 Gregorian`\nthen the configuration would be:\n\n```elixir\ndefmodule Cldr.Calendar.England do\n  use Cldr.Calendar.Composite,\n    calendars: [\n      ~D[1752-09-14 Cldr.Calendar.Gregorian]\n    ],\n    base_calendar: Cldr.Calendar.Julian\n\nend\n```\n\nThe `:base_calendar` option indicates the calendar in use\nbefore any other configured calendars.  The default is\n`Cldr.Calendar.Julian`.","ref":"Cldr.Calendar.Composite.html"},{"type":"module","title":"Julian to Gregorian transition - Cldr.Calendar.Composite","doc":"One of the uses of this calendar is to define a calendar that\nreflects the transition from the Julian to the Gregorian calendar.\n\nApplicable primarily to western european countries and\nrelated colonies, the transition to the Gregorian calendar\noccurred between the 16th and 20th centuries. One strong\nreference is the [Perpetual Calendar](https://norbyhus.dk/calendar.php)\nsite maintained by [Toke Nørby](mailto:Toke.Norby@Norbyhus.dk).\n\nAn additional source of information is\n[Wikipedia](https://en.wikipedia.org/wiki/Adoption_of_the_Gregorian_calendar).","ref":"Cldr.Calendar.Composite.html#module-julian-to-gregorian-transition"},{"type":"module","title":"Multiple compositions - Cldr.Calendar.Composite","doc":"A more complex example composes more than one calendar. For example,\nEgypt used the [Coptic calendar](https://en.wikipedia.org/wiki/Coptic_calendar)\nfrom 238 BCE until Rome introduced the Julian calendar in approximately\n30 BCE. The Gregorian calendar was then introduced in 1875. Although the\nexact dates of introduction aren't known we can approximate the composition\nof calendars with:\n\n```elixir\ndefmodule Cldr.Calendar.Composite.Egypt do\n  use Cldr.Calendar.Composite,\n    calendars: [\n      ~D[-0045-01-01 Cldr.Calendar.Julian],\n      ~D[1875-09-01]\n    ],\n    base_calendar: Cldr.Calendar.Coptic\nend\n```","ref":"Cldr.Calendar.Composite.html#module-multiple-compositions"},{"type":"function","title":"Cldr.Calendar.Composite.new/2","doc":"Creates a new composite compiler.","ref":"Cldr.Calendar.Composite.html#new/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Composite.new/2","doc":"* `calendar_module` is any module name. This will be the\n  name of the composite calendar if it is successfully\n  created.\n\n* `options` is a keyword list of options.","ref":"Cldr.Calendar.Composite.html#new/2-arguments"},{"type":"function","title":"Options - Cldr.Calendar.Composite.new/2","doc":"* `:calendars` is a list of dates representing the first\n  new date at which a calendar is introduced. These dates\n  should be expressed in the calendar of the new period.\n\n* `:base_calendar` is any calendar module that is used\n  as the calendar for any dates prior to the first\n  transition. The default is `Cldr.Calendar.Julian`.","ref":"Cldr.Calendar.Composite.html#new/2-options"},{"type":"function","title":"Returns - Cldr.Calendar.Composite.new/2","doc":"* `{:ok, module}` or\n\n* `{:module_already_exists, calendar_module}`","ref":"Cldr.Calendar.Composite.html#new/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Composite.new/2","doc":"iex> Cldr.Calendar.Composite.new Cldr.Calendar.Denmark,\n    ...> calendars: ~D[1700-03-01 Cldr.Calendar.Gregorian]\n    {:ok, Cldr.Calendar.Denmark}","ref":"Cldr.Calendar.Composite.html#new/2-examples"},{"type":"module","title":"Cldr.Calendar.Composite.Compiler","doc":"","ref":"Cldr.Calendar.Composite.Compiler.html"},{"type":"extras","title":"Cldr Composite Calendars","doc":"# Cldr Composite Calendars\n\nMost calendar implementations in computer software implement the [Proleptic Gregorian Calendar](https://en.wikipedia.org/wiki/Proleptic_Gregorian_calendar) which projects the [Gregorian Calendar](https://en.wikipedia.org/wiki/Gregorian_calendar) backwards before its introduction starting in 1582.  In general use today this is acceptable since it is not common to be working with dates prior to this period.\n\nHowever for certain fields of study, the proleptic calendar is misleading. A letter or document dated in 1751 in England would be a date in the [Julian Calendar](https://en.wikipedia.org/wiki/Julian_calendar) since the Gregorian calendar wasn't introduced in England and its colonies until September 14th, 1752. This results in dates being 11 days later in the Gregorian calendar at this time compared with the Julian calendar.\n\nCalendars defined with this library support composing multiple calendars that are implemented for different time periods. While multiple calendars can be composed, the primary use case is to compose calendars that represent a continuum from the Julian calendar to the Gregorian calendar.\n\nCalendars defined with this library implement the `Calendar` behaviour and the `Cldr.Calendar` behaviour defined in the library [ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars). See `Cldr.Calendar` for further information.","ref":"readme.html"},{"type":"extras","title":"Defining a Composite Calendar - Cldr Composite Calendars","doc":"A composite calendar is definted as a series of compositions reprenting the transition from one calendar to another. For the example of the transition from Julian to Gregorian calendar in England the first date of the Gregorian calendar is September 14th, 1752.\n\n```elixir\ndefmodule England do\n  use Cldr.Calendar.Composite,\n    calendars: ~D[1752-09-14],\n    base_calendar: Cldr.Calendar.Julian\nend\n```\n\nThis configuration states that September 14th, 1752 is the first day in the Gregorian calendar. The `:base_calendar` defines the calendar in use before any other composed calendar.  Since `Cldr.Calendar.Julian` is the default `:base_calendar`, this option may be omitted resulting in the following configuration:\n\n```elixir\ndefmodule England do\n  use Cldr.Calendar.Composite,\n    calendars: ~D[1752-09-14]\nend\n```\n\nIt is also possible to define new composite calendars at runtime as well:\n```elixir\niex> Cldr.Calendar.Composite.new France, calendars: ~D[1582-12-20]\n{:ok, France}\n```\n\nA more complex example composes more than one calendar. For example, Egypt used the [Coptic calendar](https://en.wikipedia.org/wiki/Coptic_calendar) from 238 BCE until Rome introduced the Julian calendar in approximately 30 BCE. The Gregorian calendar was then introduced in 1875. Although the exact dates of introduction aren't known we can approximate the composition of calendars with:\n\n```elixir\ndefmodule Cldr.Calendar.Composite.Egypt do\n  use Cldr.Calendar.Composite,\n    calendars: [\n      ~D[-0045-01-01 Cldr.Calendar.Julian],\n      ~D[1875-09-01]\n    ],\n    base_calendar: Cldr.Calendar.Coptic\nend\n```","ref":"readme.html#defining-a-composite-calendar"},{"type":"extras","title":"Installation - Cldr Composite Calendars","doc":"Add `ex_cldr_calendars_composite` to your list of dependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:ex_cldr_calendars_composite, \"~> 1.0\"}\n  ]\nend\n```\n\nDocumentation is published at [https://hexdocs.pm/ex_cldr_calendars_composite](https://hexdocs.pm/ex_cldr_calendars_composite).","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n** Note that `ex_cldr_calendars_composite` v1.1.0 and later is supported on Elixir 1.12 and later only.","ref":"changelog.html"},{"type":"extras","title":"Cldr Calendars Composite  v1.1.0 - Changelog","doc":"This is the changelog for Cldr Calendars Composite v1.1.0 released on March 19th, 2025.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars_composite/tags)","ref":"changelog.html#cldr-calendars-composite-v1-1-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Implement `Calendar.shift_*` callbacks if the host Elixir supports them.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Use `ex_cldr_calendars` version 2.x","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars Composite  v1.0.1 - Changelog","doc":"This is the changelog for Cldr Calendars Composite v1.0.1 released on September 6th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars_composite/tags)","ref":"changelog.html#cldr-calendars-composite-v1-0-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add callbacks for `Calendar.iso_days_to_beginning_of_day/1` and `Calendar.iso_days_to_end_of_day/1`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars Composite  v1.0.0 - Changelog","doc":"This is the changelog for Cldr Calendars Composite v1.0.0 released on April 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars_composite/tags)\n\n** Note that `ex_cldr_calendars_composite` is supported on Elixir 1.10 and later only.","ref":"changelog.html#cldr-calendars-composite-v1-0-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add required `days_in_month/1` callback.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars Composite  v0.3.0 - Changelog","doc":"This is the changelog for Cldr Calendars Composite v0.2.0 released on December 16th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars_composite/tags)\n\n** Note that `ex_cldr_calendars_composite` is support on Elixir 1.10 and later only.","ref":"changelog.html#cldr-calendars-composite-v0-3-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compatibility with `ex_cldr_calendars` version 1.17 and later which have an updated behaviour specification.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars Composite  v0.2.0 - Changelog","doc":"This is the changelog for Cldr Calendars Composite v0.2.0 released on May 22nd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars_composite/tags)","ref":"changelog.html#cldr-calendars-composite-v0-2-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove warnings for Elixir 1.12","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars Composite  v0.1.0 - Changelog","doc":"This is the changelog for Cldr Calendars Composite v0.1.0 released on June 20th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars_composite/tags)","ref":"changelog.html#cldr-calendars-composite-v0-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"Initial release.","ref":"changelog.html#enhancements"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2018-2020 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}